@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -22,12 +22,10 @@ import (
 	"net/http"
 	"time"
 
-	"git.zabbix.com/ap/plugin-support/metric"
-	"git.zabbix.com/ap/plugin-support/zbxerr"
-
 	"github.com/omeid/go-yarn"
-
-	"git.zabbix.com/ap/plugin-support/plugin"
+	"golang.zabbix.com/sdk/metric"
+	"golang.zabbix.com/sdk/plugin"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 const (
